==> A.i386-pc-linux-suse8.2.tar.gz: A.i386-pc-linux-suse8.2/amd/conf_parse.h <==
/* A Bison parser, made from /home/ezk/proj/amd/am-utils-exp/A.i386-pc-linux-suse8.2/amd/../../amd/conf_parse.y, by GNU bison 1.75.  */

/* Skeleton parser for Yacc-like parsing with Bison,
   Copyright (C) 1984, 1989, 1990, 2000, 2001, 2002 Free Software Foundation, Inc.

   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation; either version 2, or (at your option)
   any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
   Foundation, Inc., 59 Temple Place - Suite 330,
   Boston, MA 02111-1307, USA.  */

/* As a special exception, when this file is copied by Bison into a
   Bison output file, you may use that output file without restriction.
   This special exception was added by the Free Software Foundation
   in version 1.24 of Bison.  */

#ifndef BISON_CONF_PARSE_H
# define BISON_CONF_PARSE_H

/* Tokens.  */
#ifndef YYTOKENTYPE
# define YYTOKENTYPE
   /* Put the tokens into the symbol table, so that GDB and other debuggers
      know about them.  */
   enum conf_tokentype {
     LEFT_BRACKET = 258,
     RIGHT_BRACKET = 259,
     EQUAL = 260,
     NEWLINE = 261,
     NONWS_STRING = 262,
     NONWSEQ_STRING = 263,
     QUOTED_NONWSEQ_STRING = 264
   };
#endif
#define LEFT_BRACKET 258
#define RIGHT_BRACKET 259
#define EQUAL 260
#define NEWLINE 261
#define NONWS_STRING 262
#define NONWSEQ_STRING 263
#define QUOTED_NONWSEQ_STRING 264




#ifndef YYSTYPE
#line 73 "conf_parse.y"
typedef union {
char *strtype;
} conf_stype;
/* Line 1281 of /usr/share/bison/yacc.c.  */
#line 62 "conf_parse.h"
# define YYSTYPE conf_stype
#endif

extern YYSTYPE conf_lval;


#endif /* not BISON_CONF_PARSE_H */

==> A.i386-pc-linux-suse9.1.tar.gz: A.i386-pc-linux-suse9.1/amd/conf_parse.h <==
/* A Bison parser, made by GNU Bison 1.875.  */

/* Skeleton parser for Yacc-like parsing with Bison,
   Copyright (C) 1984, 1989, 1990, 2000, 2001, 2002 Free Software Foundation, Inc.

   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation; either version 2, or (at your option)
   any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
   Foundation, Inc., 59 Temple Place - Suite 330,
   Boston, MA 02111-1307, USA.  */

/* As a special exception, when this file is copied by Bison into a
   Bison output file, you may use that output file without restriction.
   This special exception was added by the Free Software Foundation
   in version 1.24 of Bison.  */

/* Tokens.  */
#ifndef YYTOKENTYPE
# define YYTOKENTYPE
   /* Put the tokens into the symbol table, so that GDB and other debuggers
      know about them.  */
   enum yytokentype {
     LEFT_BRACKET = 258,
     RIGHT_BRACKET = 259,
     EQUAL = 260,
     NEWLINE = 261,
     NONWS_STRING = 262,
     NONWSEQ_STRING = 263,
     QUOTED_NONWSEQ_STRING = 264
   };
#endif
#define LEFT_BRACKET 258
#define RIGHT_BRACKET 259
#define EQUAL 260
#define NEWLINE 261
#define NONWS_STRING 262
#define NONWSEQ_STRING 263
#define QUOTED_NONWSEQ_STRING 264




#if ! defined (YYSTYPE) && ! defined (YYSTYPE_IS_DECLARED)
#line 73 "../../amd/conf_parse.y"
typedef union YYSTYPE {
char *strtype;
} YYSTYPE;
/* Line 1249 of yacc.c.  */
#line 58 "y.tab.h"
# define yystype YYSTYPE /* obsolescent; will be withdrawn */
# define YYSTYPE_IS_DECLARED 1
# define YYSTYPE_IS_TRIVIAL 1
#endif

extern YYSTYPE yylval;
